@@ -20,6 +20,19 @@ from cybrid_api_bank.model.bank import Bank
 from cybrid_api_bank.model.bank_feature import BankFeature
 from cybrid_api_bank.model.bank_list import BankList
 from cybrid_api_bank.model.bank_type import BankType
+from cybrid_api_bank.model.compliance_check import ComplianceCheck
+from cybrid_api_bank.model.compliance_check_outcome import ComplianceCheckOutcome
+from cybrid_api_bank.model.compliance_check_type import ComplianceCheckType
+from cybrid_api_bank.model.compliance_decision import ComplianceDecision
+from cybrid_api_bank.model.compliance_decision_state import ComplianceDecisionState
+from cybrid_api_bank.model.compliance_decision_type import ComplianceDecisionType
+from cybrid_api_bank.model.counterparty import Counterparty
+from cybrid_api_bank.model.counterparty_address import CounterpartyAddress
+from cybrid_api_bank.model.counterparty_aliases_inner import CounterpartyAliasesInner
+from cybrid_api_bank.model.counterparty_list import CounterpartyList
+from cybrid_api_bank.model.counterparty_name import CounterpartyName
+from cybrid_api_bank.model.counterparty_state import CounterpartyState
+from cybrid_api_bank.model.counterparty_type import CounterpartyType
 from cybrid_api_bank.model.customer import Customer
 from cybrid_api_bank.model.customer_address import CustomerAddress
 from cybrid_api_bank.model.customer_aliases_inner import CustomerAliasesInner
@@ -58,7 +71,9 @@ from cybrid_api_bank.model.identity_verification_persona_state import IdentityVe
 from cybrid_api_bank.model.identity_verification_state import IdentityVerificationState
 from cybrid_api_bank.model.identity_verification_type import IdentityVerificationType
 from cybrid_api_bank.model.identity_verification_with_details import IdentityVerificationWithDetails
-from cybrid_api_bank.model.identity_verification_with_details_all_of import IdentityVerificationWithDetailsAllOf
+from cybrid_api_bank.model.identity_verification_with_details_pii import IdentityVerificationWithDetailsPii
+from cybrid_api_bank.model.identity_verification_with_details_pii_address import IdentityVerificationWithDetailsPiiAddress
+from cybrid_api_bank.model.identity_verification_with_details_pii_name import IdentityVerificationWithDetailsPiiName
 from cybrid_api_bank.model.invoice import Invoice
 from cybrid_api_bank.model.invoice_list import InvoiceList
 from cybrid_api_bank.model.list_request_page import ListRequestPage
@@ -70,6 +85,8 @@ from cybrid_api_bank.model.payment_instruction import PaymentInstruction
 from cybrid_api_bank.model.payment_instruction_list import PaymentInstructionList
 from cybrid_api_bank.model.post_account import PostAccount
 from cybrid_api_bank.model.post_bank import PostBank
+from cybrid_api_bank.model.post_counterparty import PostCounterparty
+from cybrid_api_bank.model.post_counterparty_name import PostCounterpartyName
 from cybrid_api_bank.model.post_customer import PostCustomer
 from cybrid_api_bank.model.post_customer_address import PostCustomerAddress
 from cybrid_api_bank.model.post_customer_name import PostCustomerName
@@ -99,6 +116,7 @@ from cybrid_api_bank.model.symbol_price import SymbolPrice
 from cybrid_api_bank.model.symbol_price_response import SymbolPriceResponse
 from cybrid_api_bank.model.symbols import Symbols
 from cybrid_api_bank.model.trade import Trade
+from cybrid_api_bank.model.trade_failure_code import TradeFailureCode
 from cybrid_api_bank.model.trade_list import TradeList
 from cybrid_api_bank.model.trade_side import TradeSide
 from cybrid_api_bank.model.trade_state import TradeState
@@ -106,14 +124,12 @@ from cybrid_api_bank.model.trade_type import TradeType
 from cybrid_api_bank.model.transfer import Transfer
 from cybrid_api_bank.model.transfer_account_type import TransferAccountType
 from cybrid_api_bank.model.transfer_destination_account import TransferDestinationAccount
+from cybrid_api_bank.model.transfer_failure_code import TransferFailureCode
 from cybrid_api_bank.model.transfer_list import TransferList
 from cybrid_api_bank.model.transfer_side import TransferSide
 from cybrid_api_bank.model.transfer_source_account import TransferSourceAccount
 from cybrid_api_bank.model.transfer_state import TransferState
 from cybrid_api_bank.model.transfer_type import TransferType
-from cybrid_api_bank.model.verification_check import VerificationCheck
-from cybrid_api_bank.model.verification_check_state import VerificationCheckState
-from cybrid_api_bank.model.verification_check_type import VerificationCheckType
 from cybrid_api_bank.model.workflow import Workflow
 from cybrid_api_bank.model.workflow_state import WorkflowState
 from cybrid_api_bank.model.workflow_type import WorkflowType
